@@ -2,8 +2,8 @@ import aiohttp
 
 apimain = "https://open.neis.go.kr/hub/schoolInfo" 
         
-async def schoolinfo(param, SD_SCHUL_CODE=None, SCHUL_NM=None, SCHUL_KND_SC_NM=None, 
-LCTN_SC_NM=None, FOND_SC_NM=None):
+async def schoolinfo(param, SD_SCHUL_CODE=None, SCHUL_NM=None, 
+SCHUL_KND_SC_NM=None, LCTN_SC_NM=None, FOND_SC_NM=None):
     """
     ``param``은 필수인자값입니다.
 
@@ -19,8 +19,9 @@ LCTN_SC_NM=None, FOND_SC_NM=None):
 
     요청한값은 ``str``형식으로 반환합니다.
     """
-    paramlist = []
     
+    paramlist = []
+
     if SD_SCHUL_CODE is not None:
         SSC = f'&SD_SCHUL_CODE={SD_SCHUL_CODE}'
         paramlist.append(SSC)
